<?php

// create custom plugin settings menu
add_action( 'admin_menu', 'frontapp_create_menu' );

function frontapp_create_menu() {

	// create new top-level menu
	add_menu_page( 'Front Settings', 'Front', 'administrator', __FILE__, 'frontapp_settings_page', 'dashicons-email-alt2' );

	// call register settings function
	add_action( 'admin_init', 'register_frontapp_check_settings' );

}


function register_frontapp_check_settings() {

	// register our settings
	register_setting( 'frontapp-settings-group', 'frontapp_auth' );
	register_setting( 'frontapp-settings-group', 'frontapp_inbox' );
	register_setting( 'frontapp-settings-group', 'frontapp_freshchat' );
	register_setting( 'frontapp-settings-group', 'frontapp_chat_id' );

}


function frontapp_settings_page() {

	// Front Api Header
	$args = array(
		'headers' => array(
			'Accept'        => 'application/json',
			'Content-Type'  => 'application/json',
			'Authorization' => 'Bearer ' . stripslashes_deep( esc_attr( get_option( 'frontapp_auth' ) ) ),
		),
	);
	// Front Api Request to Validate Access Token
	$request = wp_remote_get( 'https://api.frontapp.com/me', $args );

	if ( isset( $request['body'] ) ) {

		$response = json_decode( $request['body'] );
		// Validate Access Token
		if ( isset( $response->_error ) ) {

			// Invalid
			$class   = 'notice notice-error';
			$message = 'Please, review the information.';

		} else {

			// Valid
			$class   = 'notice notice-success is-dismissible';
			$message = 'Access Token Verified for Team: ' . $response->name;

		}
	}

?>

<div class="wrap">
	<h1>Front Connector for WordPress</h1>
	<form method="post" action="options.php">
		<?php settings_fields( 'frontapp-settings-group' ); ?>
		<?php do_settings_sections( 'frontapp-settings-group' ); ?>

		<table class="form-table">
			<tr valign="top">
				<th scope="row">Access Token</th>
				<td>
					<input type="text" name="frontapp_auth" value="<?php echo esc_attr( get_option( 'frontapp_auth' ) ); ?>" class="regular-text" />
					<div class="<?php echo $class; ?>"><p><?php echo $message; ?></p></div>
					<p class="description">(You will find this information in your Front Account.)</p>
				</td>
			</tr>

			<tr valign="top">
				<th scope="row">Inbox Name</th>
				<td>
					<input type="text" name="frontapp_inbox" value="<?php echo esc_attr( get_option( 'frontapp_inbox' ) ); ?>" class="regular-text" />
					<p class="description">(Specify the inbox where your WordPress messages will be sent.)</p>
				</td>
			</tr>

			<tr valign="top">
				<th scope="row">FreshChat</th>
				<td><fieldset>
					<label><input type="radio" name="frontapp_freshchat" id="freshchatyes" value="yes" onclick="javascript:yesnoCheck();" <?php echo ( get_option( 'frontapp_freshchat' ) == 'yes' ) ? 'checked' : ''; ?>> Yes</label><br>
					<label><input type="radio" name="frontapp_freshchat" id="freshchatno" value="no" onclick="javascript:yesnoCheck();" <?php echo ( get_option( 'frontapp_freshchat' ) == 'no' ) ? 'checked' : ''; ?>> No</label>
				</fieldset></td>
			</tr>

			<tr valign="top" id="ifYes" style="display:<?php echo ( get_option( 'frontapp_freshchat' ) == 'yes' ) ? 'table-row' : 'none'; ?>">
				<th scope="row">ChatId</th>
				<td>
					<input type="text" id="frontapp_chat_id" name="frontapp_chat_id" value="<?php echo esc_attr( get_option( 'frontapp_chat_id' ) ); ?>" <?php echo ( get_option( 'frontapp_freshchat' ) == 'yes' ) ? 'required' : ''; ?>  class="regular-text" />
					<p class="description">(Specify the ChatId where your Chat messages will be sent.)</p>
				</td>
			</tr>
		</table>

		<?php submit_button(); ?>
	</form>
</div>
<script type="text/javascript">
function yesnoCheck() {
	var yes = document.getElementById('freshchatyes').checked;
	document.getElementById('ifYes').style.display = yes ? 'table-row' : 'none';
	document.getElementById('frontapp_chat_id').required = yes;
}
</script>
<?php
}
